Setting the default color cycle to a named color sequence
---------------------------------------------------------

The default color cycle may now be configured in the ``matplotlibrc`` file or
a style file to use any of the :doc:`/gallery/color/color_sequences`.  For example

.. code-block:: none

   axes.prop_cycle : cycler(color='Accent')
